@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021, SERTIT-ICube - France, https://sertit.unistra.fr/
+# Copyright 2022, SERTIT-ICube - France, https://sertit.unistra.fr/
 # This file is part of eoreader project
 #     https://github.com/sertit/eoreader
 #
@@ -40,11 +40,11 @@ from sertit.misc import ListEnum
 from sertit.rasters import XDS_TYPE
 
 from eoreader import cache, cached_property, utils
-from eoreader.bands.alias import ALL_CLOUDS, CIRRUS, CLOUDS, RAW_CLOUDS, SHADOWS
-from eoreader.bands.bands import BandNames
-from eoreader.bands.bands import OpticalBandNames as obn
+from eoreader.bands import ALL_CLOUDS, CIRRUS, CLOUDS, RAW_CLOUDS, SHADOWS, BandNames
+from eoreader.bands import OpticalBandNames as obn
+from eoreader.bands import to_str
 from eoreader.exceptions import InvalidProductError, InvalidTypeError
-from eoreader.products.optical.vhr_product import VhrProduct
+from eoreader.products import VhrProduct
 from eoreader.utils import DATETIME_FMT, EOREADER_NAME
 
 LOGGER = logging.getLogger(EOREADER_NAME)
@@ -243,7 +243,7 @@ class DimapProduct(VhrProduct):
         root, _ = self.read_mtd()
 
         # Get CRS
-        crs_name = root.findtext(".//GEODETIC_CRS_NAME")
+        crs_name = root.findtext(".//GEODETIC_CRS_CODE")
         if not crs_name:
             crs_name = root.findtext(".//PROJECTED_CRS_CODE")
             if not crs_name:
@@ -515,7 +515,7 @@ class DimapProduct(VhrProduct):
             has_band = True
         return has_band
 
-    def _load_clouds(
+    def _open_clouds(
         self,
         bands: list,
         resolution: float = None,
@@ -525,8 +525,6 @@ class DimapProduct(VhrProduct):
         """
         Load cloud files as xarrays.
 
-        CIRRUS is HEAVY_HAZE
-
         Args:
             bands (list): List of the wanted bands
             resolution (int): Band resolution in meters
@@ -582,15 +580,20 @@ class DimapProduct(VhrProduct):
                         (1, def_xarr.rio.height, def_xarr.rio.width), dtype=np.uint8
                     )
 
-            for res_id in bands:
-                if res_id in [ALL_CLOUDS, CLOUDS, RAW_CLOUDS]:
-                    band_dict[res_id] = self._create_mask(
-                        def_xarr.rename(res_id.name),
+            for band in bands:
+                if band in [ALL_CLOUDS, CLOUDS, RAW_CLOUDS]:
+                    cloud = self._create_mask(
+                        def_xarr,
                         cld_arr,
                         nodata,
                     )
                 else:
-                    raise InvalidTypeError(f"Non existing cloud band for: {res_id}")
+                    raise InvalidTypeError(f"Non existing cloud band for: {band}")
+
+                # Rename
+                band_name = to_str(band)[0]
+                cloud.attrs["long_name"] = band_name
+                band_dict[band] = cloud.rename(band_name)
 
         return band_dict
 
@@ -611,7 +614,7 @@ class DimapProduct(VhrProduct):
         .. code-block:: python
 
             >>> from eoreader.reader import Reader
-            >>> from eoreader.bands.alias import *
+            >>> from eoreader.bands import *
             >>> path = r"IMG_PHR1A_PMS_001"
             >>> prod.open_mask("ROI")
                                                          gml_id  ...                                           geometry
