@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021, SERTIT-ICube - France, https://sertit.unistra.fr/
+# Copyright 2022, SERTIT-ICube - France, https://sertit.unistra.fr/
 # This file is part of eoreader project
 #     https://github.com/sertit/eoreader
 #
@@ -35,11 +35,11 @@ from sertit.misc import ListEnum
 from sertit.rasters import XDS_TYPE
 
 from eoreader import cache, cached_property, utils
-from eoreader.bands.alias import ALL_CLOUDS, CIRRUS, CLOUDS, RAW_CLOUDS, SHADOWS
-from eoreader.bands.bands import BandNames
-from eoreader.bands.bands import OpticalBandNames as obn
+from eoreader.bands import ALL_CLOUDS, CIRRUS, CLOUDS, RAW_CLOUDS, SHADOWS, BandNames
+from eoreader.bands import OpticalBandNames as obn
+from eoreader.bands import to_str
 from eoreader.exceptions import InvalidProductError, InvalidTypeError
-from eoreader.products.optical.optical_product import OpticalProduct
+from eoreader.products import OpticalProduct
 from eoreader.utils import DATETIME_FMT, EOREADER_NAME
 
 LOGGER = logging.getLogger(EOREADER_NAME)
@@ -398,15 +398,15 @@ class LandsatProduct(OpticalProduct):
         .. code-block:: python
 
             >>> from eoreader.reader import Reader
-            >>> from eoreader.bands.alias import *
+            >>> from eoreader.bands import *
             >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
             >>> prod = Reader().open(path)
             >>> prod.get_band_paths([GREEN, RED])
             {
                 <OpticalBandNames.GREEN: 'GREEN'>:
-                    'LC08_L1GT_023030_20200518_20200527_01_T2\\LC08_L1GT_023030_20200518_20200527_01_T2_B3.TIF',
+                    'LC08_L1GT_023030_20200518_20200527_01_T2/LC08_L1GT_023030_20200518_20200527_01_T2_B3.TIF',
                 <OpticalBandNames.RED: 'RED'>:
-                    'LC08_L1GT_023030_20200518_20200527_01_T2\\LC08_L1GT_023030_20200518_20200527_01_T2_B4.TIF'
+                    'LC08_L1GT_023030_20200518_20200527_01_T2/LC08_L1GT_023030_20200518_20200527_01_T2_B4.TIF'
             }
 
         Args:
@@ -460,11 +460,11 @@ class LandsatProduct(OpticalProduct):
         # Try with XML (we don't know what collection it is)
         try:
             # Open XML metadata
-            mtd_from_path = "*_MTL.xml"
-            mtd_archived = ".*_MTL\.xml"
+            mtd_from_path = "_MTL.xml"
+            mtd_archived = "_MTL\.xml"
             mtd_data = self._read_mtd_xml(mtd_from_path, mtd_archived)
         except (InvalidProductError, FileNotFoundError):
-            mtd_name = "**_MTL.txt"
+            mtd_name = "_MTL.txt"
             if self.is_archived:
                 # We need to extract the file in memory to be used with pandas
                 tar_ds = tarfile.open(self.path, "r")
@@ -473,7 +473,10 @@ class LandsatProduct(OpticalProduct):
             else:
                 # FOR COLLECTION 1 AND 2
                 tar_ds = None
-                mtd_path = next(self.path.glob(mtd_name))
+                try:
+                    mtd_path = next(self.path.glob(f"**/*{mtd_name}"))
+                except ValueError:
+                    mtd_path = next(self.path.glob(f"*{mtd_name}"))
 
                 if not mtd_path.is_file():
                     raise InvalidProductError(
@@ -783,7 +786,7 @@ class LandsatProduct(OpticalProduct):
             has_band = False
         return has_band
 
-    def _load_clouds(
+    def _open_clouds(
         self,
         bands: list,
         resolution: float = None,
@@ -816,20 +819,20 @@ class LandsatProduct(OpticalProduct):
             qa_arr = self._read_band(landsat_qa_path, resolution=resolution, size=size)
 
             if self.product_type == LandsatProductType.L1_OLCI:
-                band_dict = self._load_olci_clouds(qa_arr, bands)
+                band_dict = self._open_olci_clouds(qa_arr, bands)
             elif self.product_type in [
                 LandsatProductType.L1_ETM,
                 LandsatProductType.L1_TM,
             ]:
-                band_dict = self._load_e_tm_clouds(qa_arr, bands)
+                band_dict = self._open_e_tm_clouds(qa_arr, bands)
             elif self.product_type == LandsatProductType.L1_MSS:
-                band_dict = self._load_mss_clouds(qa_arr, bands)
+                band_dict = self._open_mss_clouds(qa_arr, bands)
             else:
                 raise InvalidProductError(f"Invalid product type: {self.product_type}")
 
         return band_dict
 
-    def _load_mss_clouds(self, qa_arr: XDS_TYPE, band_list: list) -> dict:
+    def _open_mss_clouds(self, qa_arr: XDS_TYPE, band_list: list) -> dict:
         """
         Load cloud files as xarrays.
 
@@ -846,7 +849,7 @@ class LandsatProduct(OpticalProduct):
         Returns:
             dict, dict: Dictionary {band_name, band_array}
         """
-        bands = {}
+        band_dict = {}
 
         # Get clouds and nodata
         nodata_id = 0
@@ -861,19 +864,24 @@ class LandsatProduct(OpticalProduct):
 
         for band in band_list:
             if band == ALL_CLOUDS:
-                bands[band] = clouds
+                cloud = clouds
             elif band == CLOUDS:
-                bands[band] = clouds
+                cloud = clouds
             elif band == RAW_CLOUDS:
-                bands[band] = qa_arr
+                cloud = qa_arr
             else:
                 raise InvalidTypeError(
                     f"Non existing cloud band for Landsat-MSS sensor: {band}"
                 )
 
-        return bands
+            # Rename
+            band_name = to_str(band)[0]
+            cloud.attrs["long_name"] = band_name
+            band_dict[band] = cloud.rename(band_name)
 
-    def _load_e_tm_clouds(
+        return band_dict
+
+    def _open_e_tm_clouds(
         self, qa_arr: XDS_TYPE, band_list: Union[list, BandNames]
     ) -> dict:
         """
@@ -893,7 +901,7 @@ class LandsatProduct(OpticalProduct):
         Returns:
             dict, dict: Dictionary {band_name, band_array}
         """
-        bands = {}
+        band_dict = {}
 
         # Get clouds and nodata
         nodata = None
@@ -921,21 +929,26 @@ class LandsatProduct(OpticalProduct):
 
         for band in band_list:
             if band == ALL_CLOUDS:
-                bands[band] = self._create_mask(qa_arr, cld | shd, nodata)
+                cloud = self._create_mask(qa_arr, cld | shd, nodata)
             elif band == SHADOWS:
-                bands[band] = self._create_mask(qa_arr, shd, nodata)
+                cloud = self._create_mask(qa_arr, shd, nodata)
             elif band == CLOUDS:
-                bands[band] = self._create_mask(qa_arr, cld, nodata)
+                cloud = self._create_mask(qa_arr, cld, nodata)
             elif band == RAW_CLOUDS:
-                bands[band] = qa_arr
+                cloud = qa_arr
             else:
                 raise InvalidTypeError(
                     f"Non existing cloud band for Landsat-(E)TM sensor: {band}"
                 )
 
-        return bands
+            # Rename
+            band_name = to_str(band)[0]
+            cloud.attrs["long_name"] = band_name
+            band_dict[band] = cloud.rename(band_name)
 
-    def _load_olci_clouds(
+        return band_dict
+
+    def _open_olci_clouds(
         self, qa_arr: XDS_TYPE, band_list: Union[list, BandNames]
     ) -> dict:
         """
@@ -954,7 +967,7 @@ class LandsatProduct(OpticalProduct):
         Returns:
             dict, dict: Dictionary {band_name, band_array}
         """
-        bands = {}
+        band_dict = {}
 
         # Get clouds and nodata
         nodata = None
@@ -1005,18 +1018,23 @@ class LandsatProduct(OpticalProduct):
 
         for band in band_list:
             if band == ALL_CLOUDS:
-                bands[band] = self._create_mask(qa_arr, cld | shd | cir, nodata)
+                cloud = self._create_mask(qa_arr, cld | shd | cir, nodata)
             elif band == SHADOWS:
-                bands[band] = self._create_mask(qa_arr, shd, nodata)
+                cloud = self._create_mask(qa_arr, shd, nodata)
             elif band == CLOUDS:
-                bands[band] = self._create_mask(qa_arr, cld, nodata)
+                cloud = self._create_mask(qa_arr, cld, nodata)
             elif band == CIRRUS:
-                bands[band] = self._create_mask(qa_arr, cir, nodata)
+                cloud = self._create_mask(qa_arr, cir, nodata)
             elif band == RAW_CLOUDS:
-                bands[band] = qa_arr
+                cloud = qa_arr
             else:
                 raise InvalidTypeError(
                     f"Non existing cloud band for Landsat-OLCI sensor: {band}"
                 )
 
-        return bands
+            # Rename
+            band_name = to_str(band)[0]
+            cloud.attrs["long_name"] = band_name
+            band_dict[band] = cloud.rename(band_name)
+
+        return band_dict
