@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021, SERTIT-ICube - France, https://sertit.unistra.fr/
+# Copyright 2022, SERTIT-ICube - France, https://sertit.unistra.fr/
 # This file is part of eoreader project
 #     https://github.com/sertit/eoreader
 #
@@ -36,10 +36,10 @@ from sertit.misc import ListEnum
 from sertit.rasters import XDS_TYPE
 
 from eoreader import cache, cached_property
-from eoreader.bands.bands import BandNames
-from eoreader.bands.bands import OpticalBandNames as obn
+from eoreader.bands import BandNames
+from eoreader.bands import OpticalBandNames as obn
 from eoreader.exceptions import InvalidProductError
-from eoreader.products.optical.vhr_product import VhrProduct
+from eoreader.products import VhrProduct
 from eoreader.reader import Platform
 from eoreader.utils import DATETIME_FMT, EOREADER_NAME
 
@@ -622,7 +622,7 @@ class MaxarProduct(VhrProduct):
             (etree._Element, dict): Metadata XML root and its namespaces as a dict
         """
         mtd_from_path = ".XML"
-        mtd_archived = ".*\.XML"
+        mtd_archived = "\.XML"
 
         return self._read_mtd_xml(mtd_from_path, mtd_archived)
 
@@ -632,7 +632,7 @@ class MaxarProduct(VhrProduct):
         """
         return False
 
-    def _load_clouds(
+    def _open_clouds(
         self,
         bands: list,
         resolution: float = None,
@@ -642,8 +642,6 @@ class MaxarProduct(VhrProduct):
         """
         Load cloud files as xarrays.
 
-        CIRRUS is HEAVY_HAZE
-
         Args:
             bands (list): List of the wanted bands
             resolution (int): Band resolution in meters
@@ -652,6 +650,9 @@ class MaxarProduct(VhrProduct):
         Returns:
             dict: Dictionary {band_name, band_xarray}
         """
+        if bands:
+            LOGGER.warning("Maxar products do not provide any cloud file")
+
         return {}
 
     def _get_til_path(self) -> Union[CloudPath, Path]:
@@ -661,4 +662,4 @@ class MaxarProduct(VhrProduct):
         Returns:
             Union[CloudPath, Path]: DIMAP filepath
         """
-        return self._get_path("", "TIL")
+        return self._get_path(extension="TIL")
