@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021, SERTIT-ICube - France, https://sertit.unistra.fr/
+# Copyright 2022, SERTIT-ICube - France, https://sertit.unistra.fr/
 # This file is part of eoreader project
 #     https://github.com/sertit/eoreader
 #
@@ -37,11 +37,11 @@ from sertit.misc import ListEnum
 from sertit.rasters import XDS_TYPE
 
 from eoreader import cache, cached_property, utils
-from eoreader.bands.alias import ALL_CLOUDS, CIRRUS, CLOUDS, RAW_CLOUDS, SHADOWS
-from eoreader.bands.bands import BandNames
-from eoreader.bands.bands import OpticalBandNames as obn
+from eoreader.bands import ALL_CLOUDS, CIRRUS, CLOUDS, RAW_CLOUDS, SHADOWS, BandNames
+from eoreader.bands import OpticalBandNames as obn
+from eoreader.bands import to_str
 from eoreader.exceptions import InvalidProductError, InvalidTypeError
-from eoreader.products.optical.optical_product import OpticalProduct
+from eoreader.products import OpticalProduct
 from eoreader.utils import DATETIME_FMT, EOREADER_NAME
 
 LOGGER = logging.getLogger(EOREADER_NAME)
@@ -392,15 +392,15 @@ class PlaProduct(OpticalProduct):
         .. code-block:: python
 
             >>> from eoreader.reader import Reader
-            >>> from eoreader.bands.alias import *
+            >>> from eoreader.bands import *
             >>> path = r"SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2"
             >>> prod = Reader().open(path)
             >>> prod.get_band_paths([GREEN, RED])
             {
                 <OpticalBandNames.GREEN: 'GREEN'>:
-                'SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2\\SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2_FRE_B3.tif',
+                'SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2/SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2_FRE_B3.tif',
                 <OpticalBandNames.RED: 'RED'>:
-                'SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2\\SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2_FRE_B4.tif'
+                'SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2/SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2_FRE_B4.tif'
             }
 
         Args:
@@ -622,7 +622,7 @@ class PlaProduct(OpticalProduct):
         # but not having reliable interpretation of the radiometry or surface reflectance.
         return True
 
-    def _load_clouds(
+    def _open_clouds(
         self,
         bands: list,
         resolution: float = None,
@@ -656,9 +656,9 @@ class PlaProduct(OpticalProduct):
         nodata = self._load_nodata(resolution, size).data
 
         if bands:
-            for res_id in bands:
-                if res_id == ALL_CLOUDS:
-                    band_dict[res_id] = self._create_mask(
+            for band in bands:
+                if band == ALL_CLOUDS:
+                    cloud = self._create_mask(
                         def_xarr.rename(ALL_CLOUDS.name),
                         (
                             self.open_mask("CLOUD", resolution, size).data
@@ -667,33 +667,36 @@ class PlaProduct(OpticalProduct):
                         ),
                         nodata,
                     )
-                elif res_id == SHADOWS:
-                    band_dict[res_id] = self._create_mask(
+                elif band == SHADOWS:
+                    cloud = self._create_mask(
                         def_xarr.rename(SHADOWS.name),
                         self.open_mask("SHADOW", resolution, size).data,
                         nodata,
                     )
-                elif res_id == CLOUDS:
-                    band_dict[res_id] = self._create_mask(
+                elif band == CLOUDS:
+                    cloud = self._create_mask(
                         def_xarr.rename(CLOUDS.name),
                         self.open_mask("CLOUD", resolution, size).data,
                         nodata,
                     )
-                elif res_id == CIRRUS:
-                    band_dict[res_id] = self._create_mask(
+                elif band == CIRRUS:
+                    cloud = self._create_mask(
                         def_xarr.rename(CIRRUS.name),
                         self.open_mask("HEAVY_HAZE", resolution, size).data,
                         nodata,
                     )
-                elif res_id == RAW_CLOUDS:
-                    band_dict[res_id] = utils.read(
-                        self._get_path("udm2", "tif"), resolution, size
-                    )
+                elif band == RAW_CLOUDS:
+                    cloud = utils.read(self._get_path("udm2", "tif"), resolution, size)
                 else:
                     raise InvalidTypeError(
-                        f"Non existing cloud band for Planet: {res_id}"
+                        f"Non existing cloud band for Planet: {band}"
                     )
 
+                # Rename
+                band_name = to_str(band)[0]
+                cloud.attrs["long_name"] = band_name
+                band_dict[band] = cloud.rename(band_name)
+
         return band_dict
 
     def open_mask(
@@ -724,7 +727,7 @@ class PlaProduct(OpticalProduct):
 
         .. code-block:: python
 
-            >>> from eoreader.bands.alias import *
+            >>> from eoreader.bands import *
             >>> from eoreader.reader import Reader
             >>> path = r"SENTINEL2B_20190401-105726-885_L2A_T31UEQ_D_V2-0.zip"
             >>> prod = Reader().open(path)
