@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021, SERTIT-ICube - France, https://sertit.unistra.fr/
+# Copyright 2022, SERTIT-ICube - France, https://sertit.unistra.fr/
 # This file is part of eoreader project
 #     https://github.com/sertit/eoreader
 #
@@ -38,11 +38,11 @@ from sertit.misc import ListEnum
 from sertit.rasters import XDS_TYPE
 
 from eoreader import cache, cached_property, utils
-from eoreader.bands.alias import ALL_CLOUDS, CIRRUS, CLOUDS, RAW_CLOUDS, SHADOWS
-from eoreader.bands.bands import BandNames
-from eoreader.bands.bands import OpticalBandNames as obn
+from eoreader.bands import ALL_CLOUDS, CIRRUS, CLOUDS, RAW_CLOUDS, SHADOWS, BandNames
+from eoreader.bands import OpticalBandNames as obn
+from eoreader.bands import to_str
 from eoreader.exceptions import InvalidProductError, InvalidTypeError
-from eoreader.products.optical.optical_product import OpticalProduct
+from eoreader.products import OpticalProduct
 from eoreader.utils import DATETIME_FMT, EOREADER_NAME
 
 LOGGER = logging.getLogger(EOREADER_NAME)
@@ -52,10 +52,10 @@ LOGGER = logging.getLogger(EOREADER_NAME)
 class S2ProductType(ListEnum):
     """Sentinel-2 products types (L1C or L2A)"""
 
-    L1C = "L1C"
+    L1C = "Level-1C"
     """L1C: https://sentinel.esa.int/web/sentinel/user-guides/sentinel-2-msi/product-types/level-1c"""
 
-    L2A = "L2A"
+    L2A = "Level-2A"
     """L2A: https://sentinel.esa.int/web/sentinel/user-guides/sentinel-2-msi/product-types/level-2a"""
 
 
@@ -185,11 +185,13 @@ class S2Product(OpticalProduct):
 
         # Open identifier
         try:
-            name = root.findtext(".//PRODUCT_URI")
+            product_lvl = root.findtext(".//PROCESSING_LEVEL")
         except TypeError:
-            raise InvalidProductError("PRODUCT_URI not found in datatake metadata!")
+            raise InvalidProductError(
+                "PROCESSING_LEVEL not found in datatake metadata!"
+            )
 
-        if "MSIL2A" in name:
+        if product_lvl == S2ProductType.L2A.value:
             self.product_type = S2ProductType.L2A
             self.band_names.map_bands(
                 {
@@ -207,7 +209,7 @@ class S2Product(OpticalProduct):
                     obn.SWIR_2: "12",
                 }
             )
-        elif "MSIL1C" in name:
+        elif product_lvl == S2ProductType.L1C.value:
             self.product_type = S2ProductType.L1C
             self.band_names.map_bands(
                 {
@@ -410,7 +412,7 @@ class S2Product(OpticalProduct):
         .. code-block:: python
 
             >>> from eoreader.reader import Reader
-            >>> from eoreader.bands.alias import *
+            >>> from eoreader.bands import *
             >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
             >>> prod = Reader().open(path)
             >>> prod.get_band_paths([GREEN, RED])
@@ -546,7 +548,7 @@ class S2Product(OpticalProduct):
         .. code-block:: python
 
             >>> from eoreader.reader import Reader
-            >>> from eoreader.bands.alias import *
+            >>> from eoreader.bands import *
             >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
             >>> prod.open_mask("NODATA", GREEN)
             Empty GeoDataFrame
@@ -857,7 +859,7 @@ class S2Product(OpticalProduct):
         gen_time = datetime.strptime(gen_time, "%Y-%m-%dT%H:%M:%S.%fZ").strftime(
             "%H%M%S"
         )
-        return f"{self.get_datetime()}_{self.platform.name}_{self.tile_name}_{self.product_type.value}_{gen_time}"
+        return f"{self.get_datetime()}_{self.platform.name}_{self.tile_name}_{self.product_type.name}_{gen_time}"
 
     @cache
     def get_mean_sun_angles(self) -> (float, float):
@@ -943,7 +945,7 @@ class S2Product(OpticalProduct):
             has_band = True
         return has_band
 
-    def _load_clouds_lt_4_0(
+    def _open_clouds_lt_4_0(
         self,
         bands: list,
         resolution: float = None,
@@ -980,31 +982,36 @@ class S2Product(OpticalProduct):
 
             for band in bands:
                 if band == ALL_CLOUDS:
-                    band_dict[band] = self._rasterize(def_band, cloud_vec, nodata)
+                    cloud = self._rasterize(def_band, cloud_vec, nodata)
                 elif band == CIRRUS:
                     try:
                         cirrus = cloud_vec[cloud_vec.maskType == "CIRRUS"]
                     except AttributeError:
                         # No masktype -> empty
                         cirrus = gpd.GeoDataFrame(geometry=[], crs=cloud_vec.crs)
-                    band_dict[band] = self._rasterize(def_band, cirrus, nodata)
+                    cloud = self._rasterize(def_band, cirrus, nodata)
                 elif band == CLOUDS:
                     try:
                         clouds = cloud_vec[cloud_vec.maskType == "OPAQUE"]
                     except AttributeError:
                         # No masktype -> empty
                         clouds = gpd.GeoDataFrame(geometry=[], crs=cloud_vec.crs)
-                    band_dict[band] = self._rasterize(def_band, clouds, nodata)
+                    cloud = self._rasterize(def_band, clouds, nodata)
                 elif band == RAW_CLOUDS:
-                    band_dict[band] = self._rasterize(def_band, cloud_vec, nodata)
+                    cloud = self._rasterize(def_band, cloud_vec, nodata)
                 else:
                     raise InvalidTypeError(
                         f"Non existing cloud band for Sentinel-2: {band}"
                     )
 
+                # Rename
+                band_name = to_str(band)[0]
+                cloud.attrs["long_name"] = band_name
+                band_dict[band] = cloud.rename(band_name)
+
         return band_dict
 
-    def _load_clouds_gt_4_0(
+    def _open_clouds_gt_4_0(
         self,
         bands: list,
         resolution: float = None,
@@ -1034,21 +1041,29 @@ class S2Product(OpticalProduct):
 
             for band in bands:
                 if band == ALL_CLOUDS:
-                    band_dict[band] = cloud_vec[0, :, :] | cloud_vec[1, :, :]
+                    cloud = cloud_vec[0, :, :] | cloud_vec[1, :, :]
                 elif band == CIRRUS:
-                    band_dict[band] = cloud_vec[1, :, :]  # CIRRUS = band 2
+                    cloud = cloud_vec[1, :, :]  # CIRRUS = band 2
                 elif band == CLOUDS:
-                    band_dict[band] = cloud_vec[0, :, :]  # OPAQUE = band 1
+                    cloud = cloud_vec[0, :, :]  # OPAQUE = band 1
                 elif band == RAW_CLOUDS:
-                    band_dict[band] = cloud_vec
+                    cloud = cloud_vec
                 else:
                     raise InvalidTypeError(
                         f"Non existing cloud band for Sentinel-2: {band}"
                     )
 
+                if len(cloud.shape) == 2:
+                    cloud = cloud.expand_dims(dim="band", axis=0)
+
+                # Rename
+                band_name = to_str(band)[0]
+                cloud.attrs["long_name"] = band_name
+                band_dict[band] = cloud.rename(band_name)
+
         return band_dict
 
-    def _load_clouds(
+    def _open_clouds(
         self,
         bands: list,
         resolution: float = None,
@@ -1070,9 +1085,9 @@ class S2Product(OpticalProduct):
             dict: Dictionary {band_name, band_xarray}
         """
         if self._processing_baseline_lt_4_0:
-            return self._load_clouds_lt_4_0(bands, resolution, size, **kwargs)
+            return self._open_clouds_lt_4_0(bands, resolution, size, **kwargs)
         else:
-            return self._load_clouds_gt_4_0(bands, resolution, size, **kwargs)
+            return self._open_clouds_gt_4_0(bands, resolution, size, **kwargs)
 
     def _rasterize(
         self, xds: XDS_TYPE, geometry: gpd.GeoDataFrame, nodata: np.ndarray
