@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021, SERTIT-ICube - France, https://sertit.unistra.fr/
+# Copyright 2022, SERTIT-ICube - France, https://sertit.unistra.fr/
 # This file is part of eoreader project
 #     https://github.com/sertit/eoreader
 #
@@ -35,12 +35,11 @@ from sertit import files, rasters, rasters_rio, vectors
 from sertit.rasters import XDS_TYPE
 
 from eoreader import cache, cached_property, utils
-from eoreader.bands.alias import ALL_CLOUDS, CIRRUS, CLOUDS, RAW_CLOUDS, SHADOWS
-from eoreader.bands.bands import BandNames
-from eoreader.bands.bands import OpticalBandNames as obn
+from eoreader.bands import ALL_CLOUDS, CIRRUS, CLOUDS, RAW_CLOUDS, SHADOWS, BandNames
+from eoreader.bands import OpticalBandNames as obn
+from eoreader.bands import to_str
 from eoreader.exceptions import InvalidProductError, InvalidTypeError
-from eoreader.products.optical.optical_product import OpticalProduct
-from eoreader.products.optical.s2_product import S2ProductType
+from eoreader.products import OpticalProduct, S2ProductType
 from eoreader.utils import DATETIME_FMT, EOREADER_NAME
 
 LOGGER = logging.getLogger(EOREADER_NAME)
@@ -232,13 +231,13 @@ class S2TheiaProduct(OpticalProduct):
         .. code-block:: python
 
             >>> from eoreader.reader import Reader
-            >>> from eoreader.bands.alias import *
+            >>> from eoreader.bands import *
             >>> path = r"SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2"
             >>> prod = Reader().open(path)
             >>> prod.get_band_paths([GREEN, RED])
             {
-                <OpticalBandNames.GREEN: 'GREEN'>: 'SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2\\SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2_FRE_B3.tif',
-                <OpticalBandNames.RED: 'RED'>: 'SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2\\SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2_FRE_B4.tif'
+                <OpticalBandNames.GREEN: 'GREEN'>: 'SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2/SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2_FRE_B3.tif',
+                <OpticalBandNames.RED: 'RED'>: 'SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2/SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2_FRE_B4.tif'
             }
 
         Args:
@@ -438,7 +437,7 @@ class S2TheiaProduct(OpticalProduct):
 
         .. code-block:: python
 
-            >>> from eoreader.bands.alias import *
+            >>> from eoreader.bands import *
             >>> from eoreader.reader import Reader
             >>> path = r"SENTINEL2B_20190401-105726-885_L2A_T31UEQ_D_V2-0.zip"
             >>> prod = Reader().open(path)
@@ -536,7 +535,7 @@ class S2TheiaProduct(OpticalProduct):
             str: Condensed name
         """
         return (
-            f"{self.get_datetime()}_S2THEIA_{self.tile_name}_{self.product_type.value}"
+            f"{self.get_datetime()}_S2THEIA_{self.tile_name}_{self.product_type.name}"
         )
 
     @cache
@@ -594,7 +593,7 @@ class S2TheiaProduct(OpticalProduct):
         """
         return True
 
-    def _load_clouds(
+    def _open_clouds(
         self,
         bands: list,
         resolution: float = None,
@@ -649,30 +648,31 @@ class S2TheiaProduct(OpticalProduct):
             shadows_in_id = 5
             shadows_out_id = 6
 
-            for res_id in bands:
-                if res_id == ALL_CLOUDS:
-                    band_dict[res_id] = self._create_mask(
+            for band in bands:
+                if band == ALL_CLOUDS:
+                    cloud = self._create_mask(
                         clouds_mask, [clouds_shadows_id, cirrus_id], nodata
                     )
-                elif res_id == SHADOWS:
-                    band_dict[res_id] = self._create_mask(
+                elif band == SHADOWS:
+                    cloud = self._create_mask(
                         clouds_mask, [shadows_in_id, shadows_out_id], nodata
                     )
-                elif res_id == CLOUDS:
-                    band_dict[res_id] = self._create_mask(
-                        clouds_mask, clouds_id, nodata
-                    )
-                elif res_id == CIRRUS:
-                    band_dict[res_id] = self._create_mask(
-                        clouds_mask, cirrus_id, nodata
-                    )
-                elif res_id == RAW_CLOUDS:
-                    band_dict[res_id] = clouds_mask
+                elif band == CLOUDS:
+                    cloud = self._create_mask(clouds_mask, clouds_id, nodata)
+                elif band == CIRRUS:
+                    cloud = self._create_mask(clouds_mask, cirrus_id, nodata)
+                elif band == RAW_CLOUDS:
+                    cloud = clouds_mask
                 else:
                     raise InvalidTypeError(
                         f"Non existing cloud band for Sentinel-2 THEIA: {res_id}"
                     )
 
+                # Rename
+                band_name = to_str(band)[0]
+                cloud.attrs["long_name"] = band_name
+                band_dict[band] = cloud.rename(band_name)
+
         return band_dict
 
     def _create_mask(
