@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021, SERTIT-ICube - France, https:#sertit.unistra.fr/
+# Copyright 2022, SERTIT-ICube - France, https:#sertit.unistra.fr/
 # This file is part of eoreader project
 #     https:#github.com/sertit/eoreader
 #
@@ -35,15 +35,10 @@ from sertit.rasters import MAX_CORES, XDS_TYPE
 from sertit.vectors import WGS84
 
 from eoreader import cache, utils
-from eoreader.bands.bands import BandNames
-from eoreader.bands.bands import OpticalBandNames as obn
+from eoreader.bands import BandNames
+from eoreader.bands import OpticalBandNames as obn
 from eoreader.exceptions import InvalidProductError, InvalidTypeError
-from eoreader.products.optical.s3_product import (
-    S3DataType,
-    S3Instrument,
-    S3Product,
-    S3ProductType,
-)
+from eoreader.products import S3DataType, S3Instrument, S3Product, S3ProductType
 from eoreader.reader import Platform
 from eoreader.utils import EOREADER_NAME
 
@@ -281,7 +276,9 @@ class S3OlciProduct(S3Product):
                 filename = band
 
             # Get raw band
-            band_arr = self._read_nc(filename, subdataset)
+            band_arr = self._read_nc(
+                filename, subdataset, dtype=kwargs.get("dtype", np.float32)
+            )
 
             # Convert radiance to reflectances if needed
             # Convert first pixel by pixel before reprojection !
@@ -329,7 +326,7 @@ class S3OlciProduct(S3Product):
             dst_crs=self.crs,
             resolution=resolution,
             gcps=self._gcps,
-            nodata=self.nodata,
+            nodata=self._mask_nodata if band_arr.dtype == np.uint8 else self.nodata,
             num_threads=MAX_CORES,
             **{"SRC_METHOD": "GCP_TPS"},
         )
@@ -542,7 +539,7 @@ class S3OlciProduct(S3Product):
         """
         return False
 
-    def _load_clouds(
+    def _open_clouds(
         self,
         bands: list,
         resolution: float = None,
