@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021, SERTIT-ICube - France, https://sertit.unistra.fr/
+# Copyright 2022, SERTIT-ICube - France, https://sertit.unistra.fr/
 # This file is part of eoreader project
 #     https://github.com/sertit/eoreader
 #
@@ -45,10 +45,10 @@ from sertit.rasters import XDS_TYPE
 from shapely.geometry import Polygon, box
 
 from eoreader import cache, cached_property, utils
-from eoreader.bands.bands import BandNames
-from eoreader.bands.bands import OpticalBandNames as obn
+from eoreader.bands import BandNames
+from eoreader.bands import OpticalBandNames as obn
 from eoreader.exceptions import InvalidProductError
-from eoreader.products.optical.optical_product import OpticalProduct
+from eoreader.products import OpticalProduct
 from eoreader.utils import DATETIME_FMT, EOREADER_NAME
 
 LOGGER = logging.getLogger(EOREADER_NAME)
@@ -375,15 +375,15 @@ class S3Product(OpticalProduct):
         .. code-block:: python
 
             >>> from eoreader.reader import Reader
-            >>> from eoreader.bands.alias import *
+            >>> from eoreader.bands import *
             >>> path = "S3B_SL_1_RBT____20191115T233722_20191115T234022_20191117T031722_0179_032_144_3420_LN2_O_NT_003.SEN3"
             >>> prod = Reader().open(path)
             >>> prod.get_band_paths([GREEN, RED])
             Executing processing graph
             ...11%...21%...31%...42%...52%...62%...73%...83%... done.
             {
-                <OpticalBandNames.GREEN: 'GREEN'>: '20191115T233722_S3_SLSTR_RBT\\S1_reflectance.tif',
-                <OpticalBandNames.RED: 'RED'>: '20191115T233722_S3_SLSTR_RBT\\S2_reflectance.tif',
+                <OpticalBandNames.GREEN: 'GREEN'>: '20191115T233722_S3_SLSTR_RBT/S1_reflectance.tif',
+                <OpticalBandNames.RED: 'RED'>: '20191115T233722_S3_SLSTR_RBT/S2_reflectance.tif',
             }
 
         Args:
@@ -627,7 +627,7 @@ class S3Product(OpticalProduct):
         return mtd_el, {}
 
     def _read_nc(
-        self, filename: Union[str, obn], subdataset: str = None
+        self, filename: Union[str, obn], subdataset: str = None, dtype=np.float32
     ) -> xr.DataArray:
         """
         Read NetCDF file (as float32) and rescaled them to their true values
@@ -701,8 +701,8 @@ class S3Product(OpticalProduct):
         # BUT the xr.DataArray dimensions wont be correctly formatted !
         # Align the NetCDF behaviour on rasterio's
 
-        # Read as float32
-        nc = nc.astype(np.float32)
+        # Read as float32 (by default) or with given type
+        nc = nc.astype(dtype)
 
         # Add the band dimension
         if "band" not in nc.dims:
@@ -725,7 +725,7 @@ class S3Product(OpticalProduct):
         return nc.copy()
 
     @abstractmethod
-    def _load_clouds(
+    def _open_clouds(
         self,
         bands: list,
         resolution: float = None,
