@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021, SERTIT-ICube - France, https://sertit.unistra.fr/
+# Copyright 2022, SERTIT-ICube - France, https://sertit.unistra.fr/
 # This file is part of eoreader project
 #     https://github.com/sertit/eoreader
 #
@@ -39,17 +39,12 @@ from sertit.rasters import MAX_CORES, XDS_TYPE
 from sertit.vectors import WGS84
 
 from eoreader import cache, utils
-from eoreader.bands.alias import ALL_CLOUDS, CIRRUS, CLOUDS, RAW_CLOUDS
-from eoreader.bands.bands import BandNames
-from eoreader.bands.bands import OpticalBandNames as obn
+from eoreader.bands import ALL_CLOUDS, CIRRUS, CLOUDS, RAW_CLOUDS, BandNames
+from eoreader.bands import OpticalBandNames as obn
+from eoreader.bands import to_str
 from eoreader.exceptions import InvalidProductError, InvalidTypeError
 from eoreader.keywords import SLSTR_RAD_ADJUST, SLSTR_STRIPE, SLSTR_VIEW
-from eoreader.products.optical.s3_product import (
-    S3DataType,
-    S3Instrument,
-    S3Product,
-    S3ProductType,
-)
+from eoreader.products import S3DataType, S3Instrument, S3Product, S3ProductType
 from eoreader.reader import Platform
 from eoreader.utils import EOREADER_NAME
 
@@ -280,9 +275,9 @@ class S3SlstrProduct(S3Product):
         """
         res_str = self._resolution_to_str(resolution)
         if filename.endswith(suffix):
-            pp_name = f"{self.condensed_name}_{filename}_{suffix}_{res_str}.tif"
-        else:
             pp_name = f"{self.condensed_name}_{filename}_{res_str}.tif"
+        else:
+            pp_name = f"{self.condensed_name}_{filename}_{suffix}_{res_str}.tif"
 
         return self._get_band_folder(writable=writable).joinpath(pp_name)
 
@@ -412,10 +407,12 @@ class S3SlstrProduct(S3Product):
             )
 
             # Get raw band
-            band_arr = self._read_nc(filename, subdataset)
+            band_arr = self._read_nc(
+                filename, subdataset, dtype=kwargs.get("dtype", np.float32)
+            )
 
             # Radiance pre process (BT bands are given in BT !)
-            if band_name in SLSTR_RAD_BANDS:
+            if not kwargs.get("flags", False) and band_name in SLSTR_RAD_BANDS:
                 # Adjust radiance if needed
                 # Get the user's radiance adjustment if existing
                 rad_adjust = kwargs.get(SLSTR_RAD_ADJUST, self._rad_adjust)
@@ -531,7 +528,7 @@ class S3SlstrProduct(S3Product):
             dst_crs=self.crs,
             resolution=resolution,
             gcps=self._gcps[suffix],
-            nodata=self.nodata,
+            nodata=self._mask_nodata if band_arr.dtype == np.uint8 else self.nodata,
             num_threads=MAX_CORES,
             resampling=Resampling.nearest,
             **{"SRC_METHOD": "GCP_TPS"},
@@ -695,7 +692,6 @@ class S3SlstrProduct(S3Product):
         Returns:
             xr.DataArray: Adjusted band array
         """
-        rad_coeff = None
         try:
             band_name = self.band_names[band]
             if band_name in SLSTR_RAD_BANDS:
@@ -705,16 +701,13 @@ class S3SlstrProduct(S3Product):
                 else:
                     rad_adjust_tuple = rad_adjust
 
-                # Get the band coefficient
+                # Get the band coefficient and multiply the band
                 rad_coeff = getattr(rad_adjust_tuple, f"{band_name}_{view}")
+                band_arr *= rad_coeff
         except KeyError:
             # Not a band (ie Quality Flags) or Brilliance temperature: no adjust needed
             pass
 
-        # Correct if needed
-        if rad_coeff:
-            band_arr *= rad_coeff
-
         return band_arr
 
     def _compute_sza_img_grid(self, suffix) -> np.ndarray:
@@ -796,6 +789,8 @@ class S3SlstrProduct(S3Product):
             subdataset=self._replace(self._exception_name, band=band, suffix=suffix),
             resolution=band_arr.rio.resolution(),
             to_reflectance=False,
+            flags=True,
+            dtype=np.uint8,
         )
 
         # Open flag file
@@ -806,8 +801,8 @@ class S3SlstrProduct(S3Product):
             masked=False,
         )
 
-        # Set no data for everything that caused an exception
-        exception = np.where(qual_arr > 2, self._mask_true, self._mask_false)
+        # Set no data for everything that caused an exception (3 and more)
+        exception = np.where(qual_arr >= 3, self._mask_true, self._mask_false)
 
         # Get nodata mask
         no_data = np.where(np.isnan(band_arr.data), self._mask_true, self._mask_false)
@@ -835,7 +830,7 @@ class S3SlstrProduct(S3Product):
 
         return has_band
 
-    def _load_clouds(
+    def _open_clouds(
         self,
         bands: list,
         resolution: float = None,
@@ -908,18 +903,23 @@ class S3SlstrProduct(S3Product):
 
             for band in bands:
                 if band == ALL_CLOUDS:
-                    band_dict[band] = self._create_mask(clouds_array, all_ids, nodata)
+                    cloud = self._create_mask(clouds_array, all_ids, nodata)
                 elif band == CLOUDS:
-                    band_dict[band] = self._create_mask(clouds_array, cloud_ids, nodata)
+                    cloud = self._create_mask(clouds_array, cloud_ids, nodata)
                 elif band == CIRRUS:
-                    band_dict[band] = self._create_mask(clouds_array, cir_id, nodata)
+                    cloud = self._create_mask(clouds_array, cir_id, nodata)
                 elif band == RAW_CLOUDS:
-                    band_dict[band] = clouds_array
+                    cloud = clouds_array
                 else:
                     raise InvalidTypeError(
                         f"Non existing cloud band for Sentinel-3 SLSTR: {band}"
                     )
 
+                # Rename
+                band_name = to_str(band)[0]
+                cloud.attrs["long_name"] = band_name
+                band_dict[band] = cloud.rename(band_name)
+
         return band_dict
 
     def _create_mask(
