@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021, SERTIT-ICube - France, https://sertit.unistra.fr/
+# Copyright 2022, SERTIT-ICube - France, https://sertit.unistra.fr/
 # This file is part of eoreader project
 #     https://github.com/sertit/eoreader
 #
@@ -43,7 +43,7 @@ from shapely.geometry import box
 from eoreader import cached_property, utils
 from eoreader.bands.bands import BandNames
 from eoreader.env_vars import DEM_PATH
-from eoreader.products.optical.optical_product import OpticalProduct
+from eoreader.products import OpticalProduct
 from eoreader.utils import EOREADER_NAME
 
 LOGGER = logging.getLogger(EOREADER_NAME)
@@ -152,7 +152,7 @@ class VhrProduct(OpticalProduct):
         .. code-block:: python
 
             >>> from eoreader.reader import Reader
-            >>> from eoreader.bands.alias import *
+            >>> from eoreader.bands import *
             >>> path = r"IMG_PHR1B_PMS_001"
             >>> prod = Reader().open(path)
             >>> prod.get_band_paths([GREEN, RED])
@@ -403,7 +403,9 @@ class VhrProduct(OpticalProduct):
 
         return band_arrays
 
-    def _get_path(self, filename: str, extension: str) -> Union[CloudPath, Path]:
+    def _get_path(
+        self, filename: str = "", extension: str = ""
+    ) -> Union[CloudPath, Path]:
         """
         Get either the archived path of the normal path of an asset
 
@@ -417,13 +419,16 @@ class VhrProduct(OpticalProduct):
         """
         path = []
         try:
+            if filename and not filename.startswith("*"):
+                filename = f"*{filename}"
+
             if self.is_archived:
                 path = files.get_archived_rio_path(
                     self.path,
-                    f".*{filename}.*\.{extension}",
+                    f".{filename}.*\.{extension}",
                 )
             else:
-                path = next(self.path.glob(f"*{filename}*.{extension}"))
+                path = next(self.path.glob(f"{filename}*.{extension}"))
 
         except (FileNotFoundError, IndexError):
             LOGGER.warning(
