@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021, SERTIT-ICube - France, https://sertit.unistra.fr/
+# Copyright 2022, SERTIT-ICube - France, https://sertit.unistra.fr/
 # This file is part of eoreader project
 #     https://github.com/sertit/eoreader
 #
@@ -48,8 +48,8 @@ from sertit.rasters import XDS_TYPE
 from sertit.snap import MAX_CORES
 
 from eoreader import cache, cached_property, utils
+from eoreader.bands import *
 from eoreader.bands import index
-from eoreader.bands.alias import *
 from eoreader.bands.bands import BandNames
 from eoreader.env_vars import CI_EOREADER_BAND_FOLDER, DEM_PATH
 from eoreader.exceptions import InvalidProductError
@@ -146,6 +146,7 @@ class Product:
         # Mask values
         self._mask_true = 1
         self._mask_false = 0
+        self._mask_nodata = 255
 
         self.platform = None
         """Product platform, such as Sentinel-2"""
@@ -212,17 +213,7 @@ class Product:
 
     def __del__(self):
         """Cleaning up _tmp directory"""
-        # -- Delete all cached properties and functions
-        gc.collect()
-
-        # All objects collected
-        objects = [
-            i for i in gc.get_objects() if isinstance(i, functools._lru_cache_wrapper)
-        ]
-
-        # All objects cleared
-        for obj in objects:
-            obj.cache_clear()
+        self.clear()
 
         # -- Remove temp folders
         if self._tmp_output:
@@ -533,7 +524,7 @@ class Product:
         .. code-block:: python
 
             >>> from eoreader.reader import Reader
-            >>> from eoreader.bands.alias import *
+            >>> from eoreader.bands import *
             >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
             >>> prod = Reader().open(path)
             >>> prod.get_band_paths([GREEN, RED])
@@ -552,7 +543,6 @@ class Product:
         """
         raise NotImplementedError("This method should be implemented by a child class")
 
-    @cache
     @abstractmethod
     def _read_mtd(self) -> Any:
         """
@@ -582,7 +572,11 @@ class Product:
             root = files.read_archived_xml(self.path, f".*{mtd_archived}")
         else:
             try:
-                mtd_file = next(self.path.glob(f"**/*{mtd_from_path}"))
+                try:
+                    mtd_file = next(self.path.glob(f"**/*{mtd_from_path}"))
+                except ValueError:
+                    mtd_file = next(self.path.glob(f"*{mtd_from_path}"))
+
                 if isinstance(mtd_file, CloudPath):
                     try:
                         # Try using read_text (faster)
@@ -784,7 +778,7 @@ class Product:
         .. code-block:: python
 
             >>> from eoreader.reader import Reader
-            >>> from eoreader.bands.alias import *
+            >>> from eoreader.bands import *
             >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
             >>> prod = Reader().open(path)
             >>> bands = prod.load([GREEN, NDVI], resolution=20)
@@ -902,7 +896,7 @@ class Product:
         .. code-block:: python
 
             >>> from eoreader.reader import Reader
-            >>> from eoreader.bands.alias import *
+            >>> from eoreader.bands import *
             >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
             >>> prod = Reader().open(path)
             >>> prod.has_band(GREEN)
@@ -917,7 +911,7 @@ class Product:
             True
 
         Args:
-            band (Union[obn, sbn]): Optical or SAR band
+            band (Union[BandNames, Callable]): Optical or SAR band
 
         Returns:
             bool: True if the products has the specified band
@@ -936,6 +930,30 @@ class Product:
 
         return has_band
 
+    def has_bands(self, bands: Union[list, BandNames, Callable]) -> bool:
+        """
+        Does this products has the specified bands ?
+
+        By band, we mean:
+
+        - satellite band
+        - index
+        - DEM band
+        - cloud band
+
+        See `has_bands` for a code example.
+
+        Args:
+            band (Union[list, BandNames, Callable]): List (or unique value) of Optical or SAR bands
+
+        Returns:
+            bool: True if the products has the specified band
+        """
+        if not isinstance(bands, list):
+            bands = [bands]
+
+        return all([self.has_band(band) for band in set(bands)])
+
     @abstractmethod
     def _has_cloud_band(self, band: BandNames) -> bool:
         """
@@ -944,7 +962,7 @@ class Product:
         .. code-block:: python
 
             >>> from eoreader.reader import Reader
-            >>> from eoreader.bands.alias import *
+            >>> from eoreader.bands import *
             >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
             >>> prod = Reader().open(path)
             >>> prod.has_cloud_band(CLOUDS)
@@ -959,7 +977,7 @@ class Product:
         .. code-block:: python
 
             >>> from eoreader.reader import Reader
-            >>> from eoreader.bands.alias import *
+            >>> from eoreader.bands import *
             >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
             >>> prod = Reader().open(path)
             >>> prod.has_index(NDVI)
@@ -1096,15 +1114,10 @@ class Product:
         """
         Get this products DEM, warped to this products footprint and CRS.
 
-        If no DEM is giving (or non existing or non intersecting the products):
-
-        - Using EUDEM over Europe
-        - Using MERIT DEM everywhere else
-
         .. code-block:: python
 
             >>> from eoreader.reader import Reader
-            >>> from eoreader.bands.alias import *
+            >>> from eoreader.bands import *
             >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
             >>> prod = Reader().open(path)
             >>> prod.warp_dem(resolution=20)  # In meters
@@ -1324,7 +1337,7 @@ class Product:
         .. code-block:: python
 
             >>> from eoreader.reader import Reader
-            >>> from eoreader.bands.alias import *
+            >>> from eoreader.bands import *
             >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
             >>> prod = Reader().open(path)
             >>> stack = prod.stack([NDVI, MNDWI, GREEN], resolution=20)  # In meters
@@ -1476,10 +1489,10 @@ class Product:
         renamed_xarr.attrs["long_name"] = long_name
         renamed_xarr.attrs["sensor"] = self._get_platform().value
         renamed_xarr.attrs["sensor_id"] = self.sat_id
-        renamed_xarr.attrs["product_path"] = self.path
+        renamed_xarr.attrs["product_path"] = str(self.path)  # Convert to string
         renamed_xarr.attrs["product_name"] = self.name
         renamed_xarr.attrs["product_filename"] = self.filename
-        renamed_xarr.attrs["product_type"] = self.product_type
+        renamed_xarr.attrs["product_type"] = self.product_type.value
         renamed_xarr.attrs["acquisition_date"] = self.get_datetime(as_datetime=False)
         renamed_xarr.attrs["condensed_name"] = self.condensed_name
 
@@ -1573,6 +1586,22 @@ class Product:
             for tmp_file in self._tmp_process.glob("*"):
                 files.remove(tmp_file)
 
+    def clear(self):
+        """
+        Clear this product's cache
+        """
+        # -- Delete all cached properties and functions
+        gc.collect()
+
+        # All objects collected
+        objects = [
+            i for i in gc.get_objects() if isinstance(i, functools._lru_cache_wrapper)
+        ]
+
+        # All objects cleared
+        for obj in objects:
+            obj.cache_clear()
+
     def _resolution_to_str(self, resolution: Union[float, tuple, list] = None):
         """
         Convert a resolution to a normalized string
