@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021, SERTIT-ICube - France, https://sertit.unistra.fr/
+# Copyright 2022, SERTIT-ICube - France, https://sertit.unistra.fr/
 # This file is part of eoreader project
 #     https://github.com/sertit/eoreader
 #
@@ -33,7 +33,7 @@ from sertit.misc import ListEnum
 
 from eoreader import cache, cached_property
 from eoreader.exceptions import InvalidProductError
-from eoreader.products.sar.sar_product import SarProduct, SarProductType
+from eoreader.products import SarProduct, SarProductType
 from eoreader.utils import DATETIME_FMT, EOREADER_NAME
 
 LOGGER = logging.getLogger(EOREADER_NAME)
@@ -95,18 +95,33 @@ class S1Product(SarProduct):
     def _set_resolution(self) -> float:
         """
         Set product default resolution (in meters)
-
-        .. WARNING:: We assume being in High Resolution (except for WV where we must be in medium resolution)
+        See here
+        <here](https://sentinel.esa.int/web/sentinel/user-guides/sentinel-1-sar/resolutions/level-1-ground-range-detected>`_
+        for more information
         """
-        root, _ = self.read_mtd()
+        def_res = None
+        # For complex data, set regular ground range resolution provided by the constructor
+        # For Sentinel data, use the best resolution available
+        if self.product_type == S1ProductType.SLC:
+            if self.sensor_mode == S1SensorMode.SM:
+                def_res = 3.5  # Full Resolution GRD
+            elif self.sensor_mode == S1SensorMode.IW:
+                def_res = 10.0  # High  Resolution GRD
+            elif self.sensor_mode == S1SensorMode.EW:
+                def_res = 25.0  # High  Resolution GRD
+            elif self.sensor_mode == S1SensorMode.WV:
+                def_res = 25.0  # Medium Resolution GRD
 
-        # Read metadata
-        try:
-            def_res = float(root.findtext(".//rangePixelSpacing"))
-        except TypeError:
-            raise InvalidProductError(
-                "rangePixelSpacing or rowSpacing not found in metadata!"
-            )
+        if not def_res:
+            root, _ = self.read_mtd()
+
+            # Read metadata
+            try:
+                def_res = float(root.findtext(".//rangePixelSpacing"))
+            except TypeError:
+                raise InvalidProductError(
+                    "rangePixelSpacing or rowSpacing not found in metadata!"
+                )
 
         return def_res
 
