@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021, SERTIT-ICube - France, https://sertit.unistra.fr/
+# Copyright 2022, SERTIT-ICube - France, https://sertit.unistra.fr/
 # This file is part of eoreader project
 #     https://github.com/sertit/eoreader
 #
@@ -37,16 +37,16 @@ from sertit.misc import ListEnum
 from sertit.rasters import XDS_TYPE
 
 from eoreader import cached_property, utils
-from eoreader.bands.alias import (
+from eoreader.bands import BandNames
+from eoreader.bands import SarBandNames as sbn
+from eoreader.bands import (
+    SarBands,
     is_clouds,
     is_dem,
     is_index,
     is_optical_band,
     is_sar_band,
 )
-from eoreader.bands.bands import BandNames
-from eoreader.bands.bands import SarBandNames as sbn
-from eoreader.bands.bands import SarBands
 from eoreader.env_vars import DEM_PATH, DSPK_GRAPH, PP_GRAPH, SAR_DEF_RES, SNAP_DEM_NAME
 from eoreader.exceptions import InvalidBandError, InvalidProductError, InvalidTypeError
 from eoreader.products.product import Product, SensorType
@@ -270,7 +270,7 @@ class SarProduct(Product):
             >>> prod.get_default_band_path()
             Executing processing graph
             ....10%....20%....30%....40%....50%....60%....70%....80%....90% done.
-            '20191215T060906_S1_IW_GRD\\20191215T060906_S1_IW_GRD_VV.tif'
+            '20191215T060906_S1_IW_GRD/20191215T060906_S1_IW_GRD_VV.tif'
 
         Args:
             kwargs: Additional arguments
@@ -425,12 +425,12 @@ class SarProduct(Product):
         .. code-block:: python
 
             >>> from eoreader.reader import Reader
-            >>> from eoreader.bands.alias import *
+            >>> from eoreader.bands import *
             >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
             >>> prod = Reader().open(path)
             >>> prod.get_band_paths([VV, HH])
             {
-                <SarBandNames.VV: 'VV'>: '20191215T060906_S1_IW_GRD\\20191215T060906_S1_IW_GRD_VV.tif'
+                <SarBandNames.VV: 'VV'>: '20191215T060906_S1_IW_GRD/20191215T060906_S1_IW_GRD_VV.tif'
             }
             >>> # HH doesn't exist
 
@@ -533,7 +533,7 @@ class SarProduct(Product):
         .. code-block:: python
 
             >>> from eoreader.reader import Reader
-            >>> from eoreader.bands.alias import *
+            >>> from eoreader.bands import *
             >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
             >>> prod = Reader().open(path)
             >>> prod.get_existing_band_paths()
@@ -542,10 +542,10 @@ class SarProduct(Product):
             Executing processing graph
             ....10%....20%....30%....40%....50%....60%....70%....80%....90% done.
             {
-                <SarBandNames.VV: 'VV'>: '20191215T060906_S1_IW_GRD\\20191215T060906_S1_IW_GRD_VV.tif',
-                <SarBandNames.VH: 'VH'>: '20191215T060906_S1_IW_GRD\\20191215T060906_S1_IW_GRD_VH.tif',
-                <SarBandNames.VV_DSPK: 'VV_DSPK'>: '20191215T060906_S1_IW_GRD\\20191215T060906_S1_IW_GRD_VV_DSPK.tif',
-                <SarBandNames.VH_DSPK: 'VH_DSPK'>: '20191215T060906_S1_IW_GRD\\20191215T060906_S1_IW_GRD_VH_DSPK.tif'
+                <SarBandNames.VV: 'VV'>: '20191215T060906_S1_IW_GRD/20191215T060906_S1_IW_GRD_VV.tif',
+                <SarBandNames.VH: 'VH'>: '20191215T060906_S1_IW_GRD/20191215T060906_S1_IW_GRD_VH.tif',
+                <SarBandNames.VV_DSPK: 'VV_DSPK'>: '20191215T060906_S1_IW_GRD/20191215T060906_S1_IW_GRD_VV_DSPK.tif',
+                <SarBandNames.VH_DSPK: 'VH_DSPK'>: '20191215T060906_S1_IW_GRD/20191215T060906_S1_IW_GRD_VH_DSPK.tif'
             }
 
         Returns:
@@ -560,7 +560,7 @@ class SarProduct(Product):
         .. code-block:: python
 
             >>> from eoreader.reader import Reader
-            >>> from eoreader.bands.alias import *
+            >>> from eoreader.bands import *
             >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
             >>> prod = Reader().open(path)
             >>> prod.get_existing_bands()
@@ -828,8 +828,8 @@ class SarProduct(Product):
             except AssertionError:
                 if isinstance(self.path, CloudPath):
                     raise InvalidProductError(
-                        "For now, TerraSAR-X data cannot be processed while being stored in the cloud."
-                        "A bug when caching directories prevents that, see here: "
+                        f"For now, {self._get_platform().value} can't be processed while being stored in the cloud. "
+                        "A bug when caching nested directories prevents that, see here: "
                         "https://github.com/drivendataorg/cloudpathlib/issues/148"
                     )
         return out
@@ -887,6 +887,23 @@ class SarProduct(Product):
             dim_path (str): DIMAP path
             pol (str): Polarization name
         """
+
+        def interp_na(arr, dim):
+            try:
+                arr = arr.interpolate_na(dim=dim, limit=10, keep_attrs=True)
+            except ValueError:
+                try:
+                    # ValueError: Index 'y' must be monotonically increasing
+                    dim_idx = getattr(arr, dim)
+                    reversed_dim_idx = list(reversed(dim_idx))
+                    arr = arr.reindex(**{dim: reversed_dim_idx})
+                    arr = arr.interpolate_na(dim=dim, limit=10, keep_attrs=True)
+                    arr = arr.reindex(**{dim: dim_idx})
+                except ValueError:
+                    pass
+
+            return arr
+
         # Get .img file path (readable by rasterio)
         try:
             img = rasters.get_dim_img_path(dim_path, f"*{pol}*")
@@ -897,6 +914,10 @@ class SarProduct(Product):
         with rioxarray.open_rasterio(str(img)) as arr:
             arr = arr.where(arr != self._snap_no_data, np.nan)
 
+            # Interpolate if needed (interpolate na works only 1D-like, sadly)
+            arr = interp_na(arr, dim="y")
+            arr = interp_na(arr, dim="x")
+
             # Save the file as the terrain-corrected image
             file_path = os.path.join(
                 self._get_band_folder(writable=True),
@@ -934,7 +955,7 @@ class SarProduct(Product):
         .. code-block:: python
 
             >>> from eoreader.reader import Reader
-            >>> from eoreader.bands.alias import *
+            >>> from eoreader.bands import *
             >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
             >>> prod = Reader().open(path)
             >>> prod.has_cloud_band(CLOUDS)
