@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021, SERTIT-ICube - France, https://sertit.unistra.fr/
+# Copyright 2022, SERTIT-ICube - France, https://sertit.unistra.fr/
 # This file is part of eoreader project
 #     https://github.com/sertit/eoreader
 #
@@ -107,7 +107,7 @@ class Platform(ListEnum):
     """COSMO-SkyMed"""
 
     CSG = "COSMO-SkyMed 2nd Generation"
-    """COSMO-SkyMed"""
+    """COSMO-SkyMed 2nd Generation"""
 
     TSX = "TerraSAR-X"
     """TerraSAR-X"""
@@ -183,6 +183,8 @@ PLATFORM_REGEX = {
         r"_(HH|VV|VH|HV)_[LR][AD]_[DPFR]_\d{14}_\d{14}\_\d_[FC]_\d{2}[NS]_Z\d{2}_[NFB]\d{2}.h5",
     ],
     Platform.TSX: r"(TSX|TDX|PAZ)1_SAR__(SSC|MGD|GEC|EEC)_([SR]E|__)___[SH][MCLS]_[SDTQ]_[SD]RA_\d{8}T\d{6}_\d{8}T\d{6}",
+    Platform.TDX: r"TDX1_SAR__(SSC|MGD|GEC|EEC)_([SR]E|__)___[SH][MCLS]_[SDTQ]_[SD]RA_\d{8}T\d{6}_\d{8}T\d{6}",
+    Platform.PAZ: r"PAZ1_SAR__(SSC|MGD|GEC|EEC)_([SR]E|__)___[SH][MCLS]_[SDTQ]_[SD]RA_\d{8}T\d{6}_\d{8}T\d{6}",
     Platform.RS2: r"RS2_OK\d+_PK\d+_DK\d+_.{2,}_\d{8}_\d{6}(_(HH|VV|VH|HV)){1,4}_S(LC|GX|GF|CN|CW|CF|CS|SG|PG)",
     Platform.PLD: r"IMG_PHR1[AB]_(P|MS|PMS|MS-N|MS-X|PMS-N|PMS-X)_\d{3}",
     Platform.SPOT7: r"IMG_SPOT7_(P|MS|PMS|MS-N|MS-X|PMS-N|PMS-X)_\d{3}_\w",
@@ -195,7 +197,7 @@ PLATFORM_REGEX = {
     Platform.WV02: r"\d{12}_\d{2}_P\d{3}_(MUL|PAN|PSH|MOS)",
     Platform.WV03: r"\d{12}_\d{2}_P\d{3}_(MUL|PAN|PSH|MOS)",
     Platform.WV04: r"\d{12}_\d{2}_P\d{3}_(MUL|PAN|PSH|MOS)",
-    Platform.ICEYE: r"((SM|SL|SC)[HW]*_\d{5,}|ICEYE_X\d_(SM|SL|SC)H*_\d{5,}_\d{8}T\d{6})",
+    Platform.ICEYE: r"((SM|SL|SC|SLEA)[HW]*_\d{5,}|ICEYE_X\d_(SM|SL|SC|SLEA)H*_\d{5,}_\d{8}T\d{6})",
 }
 
 # Not used for now
@@ -222,6 +224,8 @@ MTD_REGEX = {
     Platform.CSK: f"{PLATFORM_REGEX[Platform.CSK][1]}\.xml",
     Platform.CSG: f"{PLATFORM_REGEX[Platform.CSG][1]}\.xml",
     Platform.TSX: f"{PLATFORM_REGEX[Platform.TSX]}\.xml",
+    Platform.TDX: f"{PLATFORM_REGEX[Platform.TSX]}\.xml",
+    Platform.PAZ: f"{PLATFORM_REGEX[Platform.TSX]}\.xml",
     Platform.RS2: [
         r"product\.xml",  # Too generic name, check also a band
         r"imagery_[HV]{2}\.tif",
@@ -240,7 +244,7 @@ MTD_REGEX = {
     Platform.WV02: r"\d{2}\w{3}\d{8}-.{4}(_R\dC\d|)-\d{12}_\d{2}_P\d{3}.TIL",
     Platform.WV03: r"\d{2}\w{3}\d{8}-.{4}(_R\dC\d|)-\d{12}_\d{2}_P\d{3}.TIL",
     Platform.WV04: r"\d{2}\w{3}\d{8}-.{4}(_R\dC\d|)-\d{12}_\d{2}_P\d{3}.TIL",
-    Platform.ICEYE: r"ICEYE_X\d_(SLC|GRD)_(SM|SL|SC)H*_\d{5,}_\d{8}T\d{6}\.xml",
+    Platform.ICEYE: r"ICEYE_X\d{1,}_(SLC|GRD)_((SM|SL|SC)H*|SLEA)_\d{5,}_\d{8}T\d{6}\.xml",
 }
 
 
@@ -334,6 +338,21 @@ class Reader:
             if is_valid:
                 sat_class = platform.name.lower() + "_product"
 
+                # Channel correctly the sensors to their generic files (just in case)
+                # TerraSAR-like sensors
+                if platform in [Platform.TDX, platform.PAZ]:
+                    sat_class = "tsx_product"
+                # Maxar-like sensors
+                elif platform in [
+                    Platform.QB,
+                    Platform.GE01,
+                    Platform.WV01,
+                    Platform.WV02,
+                    Platform.WV03,
+                    Platform.WV04,
+                ]:
+                    sat_class = "maxar_product"
+
                 # Manage both optical and SAR
                 try:
                     mod = importlib.import_module(f"eoreader.products.sar.{sat_class}")
@@ -436,6 +455,9 @@ class Reader:
             bool: True if valid name
 
         """
+        # Convert platform if needed
+        platform = Platform.convert_from(platform)[0]
+
         product_path = AnyPath(product_path)
 
         if not product_path.exists():
